@@ -1,12 +1,12 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 
-def _to_int(s):
+def _to_int(s: str) -> int | str:
     try:
         return int(s)
     except ValueError:
         return s
 
 
-__version__ = "2.8.0"
+__version__ = "2.13.5"
 version_info = tuple(_to_int(s) for s in __version__.split("."))
